@@ -3,18 +3,32 @@
 /**                                                                         **/
 /**  Antenna Visualization Toolkit                                          **/
 /**                                                                         **/
-/**  Adrian Agogino  agogino@ece.utexas.edu                                 **/
-/**  Ken Harker      kharker@cs.utexas.edu                                  **/
-/**                                                                         **/
-/**  May 1998                                                               **/
+/**  Copyright (C) 1998 Adrian Agogino, Ken Harker                          **/
+/**  Copyright (C) 2005 Joop Stakenborg                                     **/
 /**                                                                         **/
 /*****************************************************************************/
 /*****************************************************************************/
 
+/*
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
+#include <string.h>
 #include <assert.h>
 #include <time.h>
 #include <GL/gl.h>
@@ -53,7 +67,10 @@
 #define SLICES_INIT         24   /**  Disks and cylinders have many slices  **/
 #define RINGS_INIT          1    /**  Disks and cylinders have many rings   **/
 
-
+typedef void (GLAPIENTRY *callback_t)();
+#ifndef CALLBACK
+#define CALLBACK
+#endif
 /*****************************************************************************/
 /*****************************************************************************/
 /**                                                                         **/
@@ -157,7 +174,7 @@ local void    TKA_Reshape(struct Togl *togl);
 local void    TKA_Rotate(GLfloat ax, GLfloat ay, GLfloat az);
 local GLfloat TKA_Angle(GLfloat size, GLfloat distance);
 local void    TKA_Disk(GLfloat radius, GLint slices, GLint rings);
-local void    TKA_ErrorCallback(GLenum errorCode);
+      void    CALLBACK TKA_ErrorCallback(GLenum errorCode);
       void    TKA_Cylinder(GLfloat radius,
                            GLfloat height,
                              GLint slices,
@@ -165,34 +182,29 @@ local void    TKA_ErrorCallback(GLenum errorCode);
       void    TKA_Cube(GLfloat size);
 local void    TKA_Create(struct Togl *togl);
 local void    TKA_Destroy(struct Togl *togl);
-local GLint   TKA_Reset(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_Eye(struct Togl *togl, GLint argc, char **argv);
+local GLint   TKA_Reset(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_Eye(struct Togl *togl, GLint argc, CONST84 char **argv);
 local void    TKA_SetMaterial(struct Material *m);
 local void    TKA_SetLight(struct Light *l, GLfloat eyemin, GLfloat eyemax);
-local GLint   TKA_Global(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_Material(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_Light(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_StdAnt(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_LoadAnt(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_DeleteAnt(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_AddElement(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_ControlTube(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_ControlAnt(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_ChangeCurrentTube(struct Togl *togl, GLint argc,char **argv);
-local GLint   TKA_ChangeCurrentAnt(struct Togl *togl, GLint argc,char **argv);
-local GLint   TKA_DrawRFPowerDensity(struct Togl  *togl, 
-                                           GLint   argc, 
-                                            char **argv);
-local GLint   TKA_DrawVolumeData(struct Togl  *togl, GLint argc, char **argv);
-local GLint   TKA_SaveFile(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_SaveRGBImage(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_MoveCenter(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_GetVariable(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_ChangeDrawMode(struct Togl *togl, GLint argc, char **argv);
-local GLint   TKA_ChangeWireDrawMode(struct Togl  *togl, 
-                                           GLint   argc,
-                                            char **argv);
-local GLint   TKA_ChangeAntMode(struct Togl *togl, GLint argc, char **argv);
+local GLint   TKA_Global(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_Material(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_Light(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_StdAnt(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_LoadAnt(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_DeleteAnt(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_AddElement(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_ControlTube(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_ControlAnt(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_ChangeCurrentTube(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_ChangeCurrentAnt(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_DrawRFPowerDensity(struct Togl  *togl, GLint   argc, CONST84 char **argv);
+local GLint   TKA_SaveFile(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_SaveRGBImage(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_MoveCenter(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_GetVariable(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_ChangeDrawMode(struct Togl *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_ChangeWireDrawMode(struct Togl  *togl, GLint argc, CONST84 char **argv);
+local GLint   TKA_ChangeAntMode(struct Togl *togl, GLint argc, CONST84 char **argv);
 
 
 /*****************************************************************************/
@@ -258,9 +270,6 @@ local GLenum LightNum[] = {GL_LIGHT0, GL_LIGHT1, GL_LIGHT2, GL_LIGHT3,
                            GL_LIGHT4, GL_LIGHT5, GL_LIGHT6, GL_LIGHT7}; 
 
 local bool antennaChanged         = false;
-local bool antennaDBiFieldDisplay = true;
-local bool antennaSenseDisplay    = false;
-
 
 /*****************************************************************************/
 /*****************************************************************************/
@@ -277,7 +286,7 @@ GLint TKA_Init(Tcl_Interp *interp) {
 
   /**  Init quadratics  **/
   assert(Qobj = gluNewQuadric());
-  gluQuadricCallback(Qobj, GLU_ERROR, TKA_ErrorCallback);
+  gluQuadricCallback(Qobj, GLU_ERROR, (callback_t)TKA_ErrorCallback);
   gluQuadricDrawStyle(Qobj, GLU_FILL);
   gluQuadricNormals(Qobj, GLU_FLAT);
 
@@ -302,7 +311,6 @@ GLint TKA_Init(Tcl_Interp *interp) {
   Togl_CreateCommand("change_current_tube", TKA_ChangeCurrentTube);
   Togl_CreateCommand("change_current_ant", TKA_ChangeCurrentAnt);
   Togl_CreateCommand("draw_RFPowerDensity", TKA_DrawRFPowerDensity);
-  Togl_CreateCommand("drawVolumeData", TKA_DrawVolumeData);
   Togl_CreateCommand("save_file", TKA_SaveFile);
   Togl_CreateCommand("save_rgb_image", TKA_SaveRGBImage);
   Togl_CreateCommand("move_center", TKA_MoveCenter);
@@ -329,7 +337,6 @@ extern Point Center;
 local void TKA_Display(struct Togl *togl) {
 
   struct Antenna *antenna = Togl_GetClientData(togl);  /**  Antenna data   **/
-  GLfloat         position[] = {1.0, 1.0, 1.0, 0.0};   /**  Position       **/ 
   GLint           s = antenna->Global_Slices;          /**  Slices         **/
   GLint           r = antenna->Global_Rings;           /**  Rings          **/
 
@@ -480,7 +487,7 @@ local void TKA_Disk(GLfloat radius, GLint slices, GLint rings) {
 /*****************************************************************************/
 
 
-local void TKA_ErrorCallback(GLenum errorCode) {
+void CALLBACK TKA_ErrorCallback(GLenum errorCode) {
 
   const  GLubyte  *estring;  /**  Error string  **/
   
@@ -662,7 +669,7 @@ local void TKA_Destroy(struct Togl *togl) {
 /*****************************************************************************/
 
 
-local GLint TKA_Reset(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_Reset(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   TKA_Create(togl);
   Togl_PostRedisplay(togl);
@@ -687,7 +694,7 @@ local GLint TKA_Reset(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_Eye(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_Eye(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   struct Antenna *antenna = Togl_GetClientData(togl);  /**  Antenna data  **/
   GLint           result;                              /**  Result        **/
@@ -713,7 +720,7 @@ local GLint TKA_Eye(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_AddElement(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_AddElement(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   struct Antenna *antenna = Togl_GetClientData(togl);  /**  Set up antenna  **/
   GLint           result;                              /**  Result          **/
@@ -738,7 +745,7 @@ local GLint TKA_AddElement(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_StdAnt(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_StdAnt(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   char   file_name[256];  /**  Name of file  **/
   GLint  result;          /**  Result        **/
@@ -775,9 +782,8 @@ local GLint TKA_StdAnt(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_LoadAnt(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_LoadAnt(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
-  char   file_name[256];  /**  Name of file  **/
   GLint  result;          /**  Result        **/
 
   fprintf(stderr, "File Name = %s\n", argv[2]);
@@ -801,9 +807,8 @@ local GLint TKA_LoadAnt(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_DeleteAnt(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_DeleteAnt(struct Togl *togl, GLint argc, char CONST84 **argv) {
 
-  char   file_name[256];  /**  Name of file  **/
   GLint  result;          /**  Result        **/
 
   DeleteCurrentAnt();
@@ -826,13 +831,9 @@ local GLint TKA_DeleteAnt(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_ControlAnt(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_ControlAnt(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   GLint   result;  /**  Result    **/
-  double  dx;      /**  Delta x   **/
-  double  dy;      /**  Delta y   **/
-  double  dz;      /**  Delta z   **/
-  double  ds;      /**  Delta s   **/
   int     func;    /**  Function  **/
 
   if(argc >= 4) {
@@ -862,13 +863,9 @@ local GLint TKA_ControlAnt(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_ControlTube(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_ControlTube(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   GLint   result;  /**  Result    **/
-  double  dx;      /**  Delta x   **/
-  double  dy;      /**  Delta y   **/
-  double  dz;      /**  Delta z   **/
-  double  ds;      /**  Delta s   **/
   int     func;    /**  Function  **/
 
 
@@ -932,7 +929,7 @@ local GLint TKA_ControlTube(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_ChangeCurrentAnt(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_ChangeCurrentAnt(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   GLint  result;  /**  Result  **/
 
@@ -955,7 +952,7 @@ local GLint TKA_ChangeCurrentAnt(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_ChangeCurrentTube(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_ChangeCurrentTube(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   GLint  result;  /**  Result  **/
 
@@ -979,7 +976,7 @@ local GLint TKA_ChangeCurrentTube(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_ChangeDrawMode(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_ChangeDrawMode(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   GLint  result;  /**  Result  **/
 
@@ -1073,7 +1070,7 @@ local GLint TKA_ChangeDrawMode(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_ChangeWireDrawMode(struct Togl *togl,GLint argc,char **argv) {
+local GLint TKA_ChangeWireDrawMode(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   GLint  result;  /**  Result  **/
 
@@ -1107,7 +1104,7 @@ local GLint TKA_ChangeWireDrawMode(struct Togl *togl,GLint argc,char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_ChangeAntMode(struct Togl *togl,GLint argc,char **argv) {
+local GLint TKA_ChangeAntMode(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   GLint  result;  /**  Result  **/
 
@@ -1137,14 +1134,8 @@ local GLint TKA_ChangeAntMode(struct Togl *togl,GLint argc,char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_DrawRFPowerDensity(struct Togl  *togl, 
-                                         GLint   argc, 
-                                          char **argv) {
+local GLint TKA_DrawRFPowerDensity(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
-  double  dx;      /**  Delta x  **/
-  double  dy;      /**  Delta y  **/
-  double  dz;      /**  Delta z  **/
-  double  ds;      /**  Delta s  **/
   GLint   result;  /**  Result   **/
 
   if(argc >= 2) {
@@ -1160,36 +1151,6 @@ local GLint TKA_DrawRFPowerDensity(struct Togl  *togl,
 }  /**  End of DrawRFPowerDensity  **/
 
 
-/*****************************************************************************/
-/*****************************************************************************/
-/**                                                                         **/
-/**                             DrawVolumeData                              **/
-/**                                                                         **/
-/*****************************************************************************/
-/*****************************************************************************/
-
-
-local GLint TKA_DrawVolumeData(struct Togl  *togl, 
-                                     GLint   argc, 
-                                      char **argv) {
-
-  double  dx;      /**  Delta x  **/
-  double  dy;      /**  Delta y  **/
-  double  dz;      /**  Delta z  **/
-  double  ds;      /**  Delta s  **/
-  GLint   result;  /**  Result   **/
-
-  if(argc >= 2) {
-    ComputeVolumeData(true);
-  }  /**  Draw the field  **/
-  Togl_PostRedisplay(togl);
-  result = TCL_OK;
-
-  return result;
-
-}  /**  End of DrawVolumeData  **/
-
-
 /*****************************************************************************/
 /*****************************************************************************/
 /**                                                                         **/
@@ -1199,7 +1160,7 @@ local GLint TKA_DrawVolumeData(struct Togl  *togl,
 /*****************************************************************************/
 
 
-local GLint TKA_SaveFile(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_SaveFile(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   char    file_name[255];  /**  File name  **/
   GLint   result;          /**  Result     **/
@@ -1232,7 +1193,7 @@ local GLint TKA_SaveFile(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_SaveRGBImage(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_SaveRGBImage(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   char    file_name[255];  /**  File name  **/
   GLint   result;          /**  Result     **/
@@ -1265,9 +1226,8 @@ local GLint TKA_SaveRGBImage(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_MoveCenter(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_MoveCenter(struct Togl *togl, GLint argc, CONST84 char **argv) {
   struct Antenna *antenna = Togl_GetClientData(togl);  /**  Antenna data   **/
-  char    file_name[255];  /**  File name  **/
   GLint   result;          /**  Result     **/
   double dist, elevation, azimuth;
 
@@ -1299,9 +1259,8 @@ local GLint TKA_MoveCenter(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_GetVariable(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_GetVariable(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
-  char    file_name[255];  /**  File name  **/
   GLint   result;          /**  Result     **/
 
   if(argc >= 2) {
@@ -1402,7 +1361,7 @@ local void TKA_SetLight(struct Light *l, GLfloat eyemin, GLfloat eyemax) {
 /*****************************************************************************/
 
 
-local GLint TKA_Global(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_Global(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   struct Antenna *antenna = Togl_GetClientData(togl);  /**  Antenna Data  **/
   GLint           result;                              /**  Result        **/
@@ -1426,7 +1385,7 @@ local GLint TKA_Global(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_Material(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_Material(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   struct Antenna *antenna = Togl_GetClientData(togl);  /**  Antenna data   **/
   GLint           result;                              /**  Result         **/
@@ -1466,7 +1425,7 @@ local GLint TKA_Material(struct Togl *togl, GLint argc, char **argv) {
 /*****************************************************************************/
 
 
-local GLint TKA_Light(struct Togl *togl, GLint argc, char **argv) {
+local GLint TKA_Light(struct Togl *togl, GLint argc, CONST84 char **argv) {
 
   struct Antenna *antenna = Togl_GetClientData(togl);  /**  Antenna data   **/ 
   GLint           result;                              /**  Result         **/
