@@ -3,14 +3,27 @@
 /**                                                                         **/
 /**  Antenna Visualization Toolkit                                          **/
 /**                                                                         **/
-/**  Adrian Agogino  agogino@ece.utexas.edu                                 **/
-/**  Ken Harker      kharker@cs.utexas.edu                                  **/
-/**                                                                         **/
-/**  May 1998                                                               **/
+/**  Copyright (C) 1998 Adrian Agogino, Ken Harker                          **/
+/**  Copyright (C) 2005 Joop Stakenborg                                     **/
 /**                                                                         **/
 /*****************************************************************************/
 /*****************************************************************************/
 
+/*
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
 
 #include <assert.h>
 #include <stddef.h>
@@ -98,8 +111,8 @@ void ComputeColor(double val, double min, double max, GLfloat *color) {
 
 double GetBoomLength(Tube *tube) {
 
-  double  max;    /**  Max x               **/
-  double  min;    /**  Min x               **/
+  double  max=0;  /**  Max x               **/
+  double  min=0;  /**  Min x               **/
   bool    first;  /**  Is first elements?  **/
 
   first = true;  
@@ -147,8 +160,8 @@ double GetBoomLength(Tube *tube) {
 double GetBoomHeight(Tube *tube) {
 
   double  median;  /**  Our best guess so far  **/
-  double  max;     /**  Max x                  **/
-  double  min;     /**  Min x                  **/
+  double  max=0;   /**  Max x                  **/
+  double  min=0;   /**  Min x                  **/
   bool    first;   /**  Is first elements?     **/
 
   first = true;    
@@ -196,7 +209,7 @@ double GetBoomHeight(Tube *tube) {
 
 double GetVerticalHeight(Tube *tube) {
 
-  double  min;     /**  Min x                  **/
+  double  min=0;   /**  Min x                  **/
   bool    first;   /**  Is first elements?     **/
 
   first = true;    
@@ -269,7 +282,7 @@ double GetBoomWidth(Tube *tube) {
 
 double GetBoomShift(Tube *tube) {
 
-  double  min;    /**  Min x               **/
+  double  min=0;  /**  Min x               **/
   bool    first;  /**  Is first elements?  **/
 
   first = true;    
@@ -470,12 +483,9 @@ void DrawWireCurrentMagnitude(Tube *the_tube,
   double       p2x;            /**  Point 2 in X           **/
   double       p2y;            /**  Point 2 in Y           **/
   double       p2z;            /**  Point 2 in Z           **/
-  double       color_range;    /**  Range of color         **/
-  double       color_pos;      /**  Position in range      **/
   GLfloat      wire_color[4];  /**  Wire color             **/
   SegmentData *segptr;         /**  Segment data           **/
   int          i;              /**  Loop counter           **/
-  int j;
 
   p1x = the_tube->e1.x;
   p1y = the_tube->e1.y;
@@ -608,8 +618,6 @@ void DrawWireCurrentPhase(Tube *the_tube,
   double       p2x;            /**  Point 2 in X           **/
   double       p2y;            /**  Point 2 in Y           **/
   double       p2z;            /**  Point 2 in Z           **/
-  double       color_range;    /**  Range of color         **/
-  double       color_pos;      /**  Position in range      **/
   GLfloat      wire_color[4];  /**  Wire color             **/
   SegmentData *segptr;         /**  Segment data           **/
   int          i;              /**  Loop counter           **/
