@@ -3,19 +3,35 @@
 /**                                                                         **/
 /**  Antenna Visualization Toolkit                                          **/
 /**                                                                         **/
-/**  Adrian Agogino  agogino@ece.utexas.edu                                 **/
-/**  Ken Harker      kharker@cs.utexas.edu                                  **/
-/**                                                                         **/
-/**  May 1998                                                               **/
+/**  Copyright (C) 1998 Adrian Agogino, Ken Harker                          **/
+/**  Copyright (C) 2005 Joop Stakenborg                                     **/
 /**                                                                         **/
 /*****************************************************************************/
 /*****************************************************************************/
 
+/*
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ */
 
 #include <assert.h>
 #include <stddef.h>
 #include <math.h>
 #include <stdlib.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <unistd.h>
 #include <GL/gl.h>
 #include <GL/glu.h>
 #include "MyTypes.h"
@@ -264,7 +280,7 @@ void InitDisplay(void) {
 
   if(here_before == 0) {    
     if (AntennasInScene == false) 
-      TheAnts.ant_count == 0;
+    TheAnts.ant_count = 0;
     curr_step_size = 5;
     ShowRadPat     = 0;
     ShowPolSense   = 1;
@@ -357,8 +373,8 @@ void DisplayField(Ant *antData) {
 void DisplaySelectedAnt(Ant *ant, GLint slices, GLint rings, bool selected) {
 
   double   boomlength;         /**  Length of the boom           **/
-  double   boomcenter;         /**  Distance to boom center      **/
-  double   boomheight;         /**  Height of boom above ground  **/
+  double   boomcenter=0;       /**  Distance to boom center      **/
+  double   boomheight=0;       /**  Height of boom above ground  **/
   double   boomwidth;          /**  Width of boom                **/
   double   boomshift;          /**  How far we need to center    **/
   GLfloat  selected_color[4];  /**  The selected color           **/
@@ -428,7 +444,7 @@ void DisplaySelectedAnt(Ant *ant, GLint slices, GLint rings, bool selected) {
       glPopMatrix(); 
     }  /**  Only for antennas with booms  **/
  
-  }  /**  Draw only with antenna  **
+  }  /**  Draw only with antenna  **/
 
   /**  Antenna elements  **/
   glPushMatrix();
@@ -494,10 +510,10 @@ void DisplaySelectedAnt(Ant *ant, GLint slices, GLint rings, bool selected) {
 
 void DisplayAnt(GLint slices, GLint rings) {
 
-  double  median_x;    /**  Median X value               **/
-  double  median_y;    /**  Median Y value               **/
-  double  median_z;    /**  Median Z value               **/
-  double  boomheight;  /**  Height of boom above ground  **/
+  double  median_x=0;  /**  Median X value               **/
+  double  median_y=0;  /**  Median Y value               **/
+  double  median_z=0;  /**  Median Z value               **/
+  double  boomheight=0;/**  Height of boom above ground  **/
   int     i;           /**  Loop counter                 **/
   int     j;           /**  Loop counter                 **/
 
@@ -605,7 +621,7 @@ void InitAnt(Ant *ant) {
 /*****************************************************************************/
 
 
-void ReadFile(char *file_name) {
+void ReadFile(CONST84 char *file_name) {
 
   if (AntennasInScene == false) {
     TheAnts.ant_count = 0;
@@ -1073,7 +1089,7 @@ void ChangeCurrentTube(int count) {
 /*****************************************************************************/
 
 
-void GenerateNECFile(char *file_name) {
+void GenerateNECFile(CONST84 char *file_name) {
 
   curr_step_size = STEP_SIZE;
 
@@ -1092,28 +1108,6 @@ void GenerateNECFile(char *file_name) {
 
 
 /*****************************************************************************/
-/*****************************************************************************/
-/**                                                                         **/
-/**                        GenerateNECVolumeFile                            **/
-/**                                                                         **/
-/**  This function traverses the details of the antenna we have stored in   **/
-/**  memory and output a .nec file that NEC2 will load by default.          **/
-/**                                                                         **/
-/*****************************************************************************/
-/*****************************************************************************/
-
-
-void GenerateNECVolumeFile(char *file_name) {
-
-  curr_step_size = STEP_SIZE;
-  WriteVolumeCardFile(file_name, 
-                     &TheAnts.ants[TheAnts.curr_ant], 
-                      STEP_SIZE, 
-                      TheAnts.ants[TheAnts.curr_ant].frequency);
-
-}  /**  End of GenerateNECVolumeFile  **/
-
-
 /*****************************************************************************/
 /*****************************************************************************/
 /**                                                                         **/
@@ -1163,11 +1157,11 @@ void ComputeField(bool changed) {
     if ((TheAnts.ants[TheAnts.curr_ant].fieldComputed == false) ||
         (changed == true)){
 
-      ferror = remove("output_nec");
-      ferror = remove("input_nec");
+      ferror = remove("output.nec");
+      ferror = remove("input.nec");
 
       /**  Output our current antenna to disk  **/
-      GenerateNECFile("input_nec"); 
+      GenerateNECFile("input.nec"); 
   
       /**  Run NEC code on that file  **/
       parentpid = getpid();
@@ -1177,7 +1171,7 @@ void ComputeField(bool changed) {
       }  /**  Error state  **/
       if (childpid == 0) {  /**  We are child  **/
         printf("Running NEC2 code...  please stand by...\n");
-        execlp("./nec2", (char *)0);  
+        execlp("nec2", "nec2", "input.nec", "output.nec", NULL);  
         exit(-1);  /**  We should never reach here  **/
       }  /**  We are child  **/
       else {  /**  We are parent  **/
@@ -1188,17 +1182,18 @@ void ComputeField(bool changed) {
       }  /**  We are parent  **/
   
       /**  Read in results from disk  **/
-      fin  = fopen("output_nec", "rt");
+      fin  = fopen("output.nec", "rt");
       if(fin != NULL) {
         ParseFieldData(fin, &TheAnts.ants[TheAnts.curr_ant], true, true);
-      } else
-        fprintf(stderr, "Could Not Open File!!!\n");
-      close(fin);
-
-      printf("Removing temporary files...\n");
+        fclose(fin);
+      } 
+      else {
+        fprintf(stderr, "Could Not Open File output.nec!!!\n");
+        return;
+      }
       /*
-      ferror = remove("output_nec");
-      ferror = remove("input_nec"); 
+      ferror = remove("output.nec");
+      ferror = remove("input.nec"); 
       */
       printf("Field computation complete.\n");
  
@@ -1212,83 +1207,6 @@ void ComputeField(bool changed) {
 }  /**  End of ComputeField  **/
 
 
-/*****************************************************************************/
-/*****************************************************************************/
-/**                                                                         **/
-/**                          ComputeVolumeData                              **/
-/**                                                                         **/
-/**  This function calls the NEC2 code to (re)compute a volume of data.     **/
-/**  This is a three dimensional volume with a vector of scalar values at   **/
-/**  each point in (theta, phi, frequency).                                 **/
-/**                                                                         **/
-/*****************************************************************************/
-/*****************************************************************************/
-
-
-void ComputeVolumeData(bool changed) {
-
-  FILE *fin;        /**  Input file               **/
-  long  parentpid;  /**  Process ID of parent     **/
-  long  childpid;   /**  Process ID of child      **/
-  int   status;     /**  Status of child process  **/
-  int   ferror;     /**  File access error        **/
-
-  /**  Check to see if antennas exist  **/
-  if (AntennasInScene == true) {
-  
-    if ((TheAnts.ants[TheAnts.curr_ant].fieldComputed == false) ||
-        (changed == true)){
-
-      ferror = remove("output_nec");
-      ferror = remove("input_nec");
-
-      /**  Output our current antenna to disk  **/
-      GenerateNECVolumeFile("input_nec"); 
-  
-      /**  Run NEC code on that file  **/
-      parentpid = getpid();
-      if ((childpid = fork()) < 0) {
-        fprintf(stderr,"Can't fork\n");
-        exit(-2);
-      }  /**  Error state  **/
-      if (childpid == 0) {  /**  We are child  **/
-        printf("Running NEC2 code...  please stand by...\n");
-        execlp("./nec2", (char *)0);  
-        exit(-1);  /**  We should never reach here  **/
-      }  /**  We are child  **/
-      else {  /**  We are parent  **/
-        if (wait(&status) != childpid) {
-          fprintf(stderr,"Problem with child\n");
-          exit(-3);
-        }  /**  Error state  **/
-      }  /**  We are parent  **/
-  
-      /**  Read in results from disk  **/
-      fin  = fopen("output_nec", "rt");
-      if(fin != NULL) {
-        ParseVolumeData(fin, &TheAnts.ants[TheAnts.curr_ant], true, true);
-        /*printf("Homer says d'oh!\n");*/
-      } else
-        fprintf(stderr, "Could Not Open File!!!\n");
-      close(fin);
-
-      printf("Removing temporary files...\n");
-      /*
-      ferror = remove("output_nec");
-      ferror = remove("input_nec"); 
-      */
-      printf("Field computation complete.\n");
- 
-      RFPowerDensityOn = true;
-      FieldDataComputed = true;
-
-    }  /**  Need to compute field  **/
-
-  }  /**  Antennas are in scene  **/
-
-}  /**  End of ComputeVolumeData  **/
-
-
 /*****************************************************************************/
 /*****************************************************************************/
 /**                                                                         **/
