@@ -7,14 +7,25 @@ exec TkAnt "$0" "$@"
 ##                                                                           ##
 ##  Antenna Visualization Toolkit                                            ##
 ##                                                                           ##
-##  Adrian Agogino  agogino@ece.utexas.edu                                   ##
-##  Ken Harker      kharker@cs.utexas.edu                                    ##
-##                                                                           ##
-##  May 1998                                                                 ##
+##  Copyright (C) 1998 Adrian Agogino, Ken Harker                            ##
+##  Copyright (C) 2005 Joop Stakenborg                                       ##
 ##                                                                           ##
 ###############################################################################
 ###############################################################################
 
+## This program is free software; you can redistribute it and/or modify
+## it under the terms of the GNU General Public License as published by
+## the Free Software Foundation; either version 2 of the License, or
+## (at your option) any later version.
+##
+## This program is distributed in the hope that it will be useful,
+## but WITHOUT ANY WARRANTY; without even the implied warranty of
+## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+## GNU Library General Public License for more details.
+##
+## You should have received a copy of the GNU General Public License
+## along with this program; if not, write to the Free Software
+## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 ###############################################################################
 ###############################################################################
@@ -65,19 +76,19 @@ set AbleLs {}
 set LightAbleLs {}
 
 # our font
-set font screen16
+set font "-*-helvetica-medium-r-*-*-*-*-*-*-*-*-*"
 
 # our bold font
-set boldfont screen-bold16
+set boldfont "-*-helvetica-bold-r-*-*-*-*-*-*-*-*-*"
 
 # our relief
 set relief groove
 
 # our borderwidth
-set borderwidth 2
+set borderwidth 1
 
 #our pad
-set pad 4
+set pad 1
 
 # our enable color
 set enablecolor ""
@@ -123,7 +134,7 @@ proc CreateUserInterface {} {
       enablecolor disablecolor AntType
 
   # Give it a title
-  wm title . "Antenna Visualization Toolkit, Adrian Agogino, Kenneth Harker"
+  wm title . "Antenna Visualization Toolkit: Antennavis"
 
   # the basics
   set WTopFrame .top
@@ -145,7 +156,7 @@ proc CreateUserInterface {} {
   set WAntennaFrame $WTopFrame.antennaFrame
   frame $WAntennaFrame -borderwidth $borderwidth -relief $relief
   set WAntenna $WAntennaFrame.antenna
-  togl $WAntenna -rgba true -double true -depth true -width 500 -height 500
+  togl $WAntenna -rgba true -double true -depth true -height 390
   pack $WAntenna -fill both -fill both -expand 1 
   pack $WAntennaFrame -side left -fill both -expand 1 -padx $pad -pady $pad
 
@@ -196,10 +207,6 @@ proc CreateUserInterface {} {
          -font $font 
   pack $WsaveImageButton -side top -pady $pad
 
-  set WMInsertAnt $WFileControlFrame.insertant
-  chooser $WMInsertAnt AntType {"Load Yagi"} {InsertAnt {$AntType}}
-  pack $WMInsertAnt -side bottom -pady $pad
-
   pack $WFileControlFrame -side left -padx $pad -pady $pad -fill y
 
 
@@ -242,12 +249,6 @@ proc CreateUserInterface {} {
          -font $font 
   pack $Wdraw_RFPowerDensityButton -side top -pady $pad
 
-  set WdrawVolumeDataButton $WVisControlFrame.drawVolumeDataButton
-  button $WdrawVolumeDataButton -relief $relief -text "Isosurfaces" \
-         -command {$WAntenna drawVolumeData} \
-         -font $font 
-  pack $WdrawVolumeDataButton -side top -pady $pad
-
   set MultAntsVariable 0
   set SingleAntButton $WVisControlFrame.single_ant_button
   radiobutton $SingleAntButton -text "Current Antenna" -font $font \
@@ -597,7 +598,7 @@ proc CreateUserInterface {} {
   ###########################################################################
 
 
-  set WGControlFrame $WGRightFrame.controlFrame
+  set WGControlFrame $WDisplayFrame.controlFrame
   frame $WGControlFrame
   label $WGControlFrame.label -font $font
   pack $WGControlFrame.label -side left -padx $pad -pady $pad
@@ -607,10 +608,6 @@ proc CreateUserInterface {} {
       -font $font 
   pack $WexitButton -side right -pady $pad
 
-  set WhelpButton $WGControlFrame.helpButton
-  button $WhelpButton -relief $relief -text "Help" \
-      -command "CreateHelpWindow" -font $font
-  pack $WhelpButton -side right -pady $pad
   set WresetButton $WGControlFrame.resetButton
   button $WresetButton -relief $relief -text "Reset" \
       -command "$WAntenna reset; UpdateAntennaControl; UpdateLight; \
@@ -646,34 +643,6 @@ proc CreateUserInterface {} {
 }
 
 
-###############################################################################
-###############################################################################
-##                                                                           ##
-##                            Help Window System                             ##
-##                                                                           ##
-###############################################################################
-###############################################################################
-
-
-proc CreateHelpWindow {} {
-
-  set font screen16
-
-  if {[info commands ".help"] != {}} {destroy .help}
-  toplevel .help
-  wm title .help "Antenna Visualization Toolkit Help"
-  label .help.text -justify left -font $font -text \
-  "This is where the help text goes!"
-
-  button .help.close -relief groove -text "close" -command "destroy .help" \
-      -font $font
-  
-  pack .help.text -side top
-  pack .help.close -side bottom
-
-}
-
-
 ###############################################################################
 ###############################################################################
 ##                                                                           ##
